@@ -7,16 +7,13 @@
 
 #include <amorbubble.h>
 #include <amorbubble.moc>
-#include <qbitmap.h>
 #include <qpainter.h>
 #include <ktextbrowser.h>
 #include <qtooltip.h>
-#include <kapp.h>
-#include <kstddirs.h>
-#include <kdebug.h>
-#include <klocale.h>
+#include <kstandarddirs.h>
 #include <X11/Xlib.h>
 #include <X11/extensions/shape.h>
+#include <qtimer.h>
 
 #define ARROW_WIDTH     10
 #define ARROW_HEIGHT    12
@@ -29,7 +26,7 @@
 // Constructor
 //
 AmorBubble::AmorBubble()
-	: QWidget(0, 0, WStyle_Customize | WStyle_NoBorder )
+	: QWidget(0, 0, WStyle_Customize | WStyle_NoBorder | WX11BypassWM )
 {
     mOriginX = 0;
     mOriginY = 0;
@@ -38,7 +35,8 @@ AmorBubble::AmorBubble()
     mBrowser->setMargin( 0 );
     QColorGroup clgrp = mBrowser->colorGroup();
     clgrp.setColor(QColorGroup::Text, Qt::black);
-    mBrowser->setPaperColorGroup( clgrp );
+    //Laurent QTextBrowser didn't have this function FIX me
+    //mBrowser->setPaperColorGroup( clgrp );
     mBrowser->setPaper( QToolTip::palette().active().brush( QColorGroup::Background ) );
     mBrowser->setVScrollBarMode( QTextBrowser::AlwaysOff );
     mBrowser->setHScrollBarMode( QTextBrowser::AlwaysOff );
