@@ -25,6 +25,7 @@
 
 class QSlider;
 class MoonWidget;
+class QPushButton;
 
 class KMoonDlg : public KDialogBase {
     Q_OBJECT
@@ -39,6 +40,7 @@ private:
     MoonWidget *moon;
     int angle;
     bool north;
+    QPushButton *hemitoggle;
 
  private slots:
     void valueChanged(int);
