@@ -670,7 +670,7 @@ bool kweather::attach()
                 if (!client->isApplicationRegistered("KWeatherService"))
                 {
                         kdDebug() << "Could not find service so I am starting it..." << endl;
-                        if(!KApplication::startServiceByName("KWeatherService",QStringList(), &error,&appID ))
+                        if(!KApplication::startServiceByDesktopName("kweatherservice",QStringList(), &error,&appID ))
 
                         {
                                 kdDebug() << "Starting KWeatherService failed with message: " << error << endl;
