@@ -1,4 +1,4 @@
-/* $Id: reportmain.cpp,v 1.3 2002/05/02 23:11:45 nhasan Exp $ */
+/* $Id: reportmain.cpp,v 1.3.2.1 2003/02/03 01:21:08 mueller Exp $ */
 
 #include <stdlib.h>
 #include <kapplication.h>
@@ -28,7 +28,7 @@ int main (int argc, char *argv[])
 	QCString appID = "";
 	if (!client->isApplicationRegistered("kweatherservice"))
 			{
-				if(KApplication::startServiceByName("kweatherservice",QStringList(), &error, &appID ))
+				if(KApplication::startServiceByDesktopName("kweatherservice",QStringList(), &error, &appID ))
 				{
 					kdDebug() << "Starting kweatherservice failed with message: " << error << endl;
 					exit(0);
