@@ -16,8 +16,9 @@ extern "C"
   KPanelApplet *init(QWidget *parent, const QString& configFile)
   {
     KGlobal::locale()->insertCatalogue("kworldclock");
+    KGlobal::locale()->insertCatalogue("timezones"); // For time zone translation
     return new KWWApplet(configFile, KPanelApplet::Normal,
-			 KPanelApplet::About | KPanelApplet::Help | KPanelApplet::Preferences,
+			 0,
 			 parent, "kwwapplet");
   }
 }
@@ -31,7 +32,7 @@ KWWApplet::KWWApplet(const QString& configFile, Type type, int actions,
   KGlobal::iconLoader()->addAppDir("kworldwatch");
 
   QVBoxLayout *vbox = new QVBoxLayout(this, 0,0);
-  
+
   map = new MapWidget(true, true, this);
   map->load(config());
   vbox->addWidget(map);
