@@ -5,7 +5,7 @@
 #include <qwidget.h>
 #include <qstring.h>
 #include <qframe.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 
 class QLabel;
@@ -98,7 +98,7 @@ private:
   void createDialog();
 
   SimpleFlow *_flow;  
-  QList<ZoneClock> _clocks;
+  QPtrList<ZoneClock> _clocks;
   ClockDialog *_dlg;
 
 };
